@@ -3,9 +3,10 @@ from opensanctions.helpers.emails import clean_emails
 from opensanctions.helpers.phones import clean_phones
 from opensanctions.helpers.addresses import make_address, apply_address
 from opensanctions.helpers.sanctions import make_sanction
-from opensanctions.helpers.lookups import type_lookup
 from opensanctions.helpers.features import apply_feature
 from opensanctions.helpers.dates import extract_years, parse_date
+from opensanctions.helpers.excel import convert_excel_cell
+from opensanctions.helpers.constraints import check_person_cutoff
 
 __all__ = [
     "clean_gender",
@@ -14,8 +15,9 @@ __all__ = [
     "make_address",
     "apply_address",
     "make_sanction",
-    "type_lookup",
     "extract_years",
     "parse_date",
     "apply_feature",
+    "convert_excel_cell",
+    "check_person_cutoff",
 ]
